package com.xunmei.system.service;

import java.util.List;

import com.xunmei.system.api.domain.SysOrg;
import com.xunmei.system.domain.SysOrgExtend;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xunmei.common.core.web.page.TableDataInfo;

/**
 * 机构扩展Service接口
 *
 * @author xunmei
 * @date 2023-08-16
 */
public interface ISysOrgExtendService extends IService<SysOrgExtend> {
    /**
     * 查询机构扩展
     *
     * @param id 机构扩展主键
     * @return 机构扩展
     */
    SysOrgExtend selectSysOrgExtendById(Long id);

    /**
     *
     * @param id
     * @return
     */
    SysOrgExtend selectSysOrgExtendByOrgId(Long id);

    /**
     * 查询机构扩展列表
     *
     * @param sysOrgExtend 机构扩展
     * @return 机构扩展集合
     */
    List<SysOrgExtend> selectSysOrgExtendList(SysOrgExtend sysOrgExtend);

    /**
     * 新增机构扩展
     *
     * @param sysOrgExtend 机构扩展
     * @return 结果
     */
    int insertSysOrgExtend(SysOrgExtend sysOrgExtend);

    /**
     * 修改机构扩展
     *
     * @param sysOrgExtend 机构扩展
     * @return 结果
     */
    int updateSysOrgExtend(SysOrgExtend sysOrgExtend);

    /**
     * 批量删除机构扩展
     *
     * @param ids 需要删除的机构扩展主键集合
     * @return 结果
     */
    int deleteSysOrgExtendByIds(Long[] ids);

    /**
     * 删除机构扩展信息
     *
     * @param id 机构扩展主键
     * @return 结果
     */
    int deleteSysOrgExtendById(Long id);

    /**
     * 查询机构扩展分页数据
     *
     * @param sysOrgExtend 查询条件对象
     * @return Page
     */
    TableDataInfo<SysOrgExtend> selectPage(SysOrgExtend sysOrgExtend);
}
