package com.xunmei.system.mapper;

import java.util.List;

import com.xunmei.system.domain.SysOrgExtend;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 机构扩展Mapper接口
 *
 * @author xunmei
 * @date 2023-08-16
 */
public interface SysOrgExtendMapper extends BaseMapper<SysOrgExtend> {
    /**
     * 查询机构扩展
     *
     * @param id 机构扩展主键
     * @return 机构扩展
     */
     SysOrgExtend selectSysOrgExtendById(Long id);

    /**
     * 查询机构扩展列表
     *
     * @param sysOrgExtend 机构扩展
     * @return 机构扩展集合
     */
     List<SysOrgExtend> selectSysOrgExtendList(SysOrgExtend sysOrgExtend);

    /**
     * 新增机构扩展
     *
     * @param sysOrgExtend 机构扩展
     * @return 结果
     */
     int insertSysOrgExtend(SysOrgExtend sysOrgExtend);

    /**
     * 修改机构扩展
     *
     * @param sysOrgExtend 机构扩展
     * @return 结果
     */
     int updateSysOrgExtend(SysOrgExtend sysOrgExtend);

    /**
     * 删除机构扩展
     *
     * @param id 机构扩展主键
     * @return 结果
     */
     int deleteSysOrgExtendById(Long id);

    /**
     * 批量删除机构扩展
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysOrgExtendByIds(Long[] ids);
}
